/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * FileCommander.java
 * Copyright (C) 2016-2018 University of Waikato, Hamilton, New Zealand
 *
 */

package adams.gui.menu;

import adams.core.option.UserMode;
import adams.gui.application.AbstractApplicationFrame;
import adams.gui.core.GUIHelper;
import adams.gui.tools.FileCommanderPanel;

/**
 * Opens the File commander.
 * You can supply the directories for left and right panel. If only one
 * is supplied then it is used for both.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 */
public class FileCommander
  extends AbstractParameterHandlingMenuItemDefinition {

  /** for serialization. */
  private static final long serialVersionUID = 7907139922742800770L;

  /**
   * Initializes the menu item with no owner.
   */
  public FileCommander() {
    this(null);
  }

  /**
   * Initializes the menu item.
   *
   * @param owner	the owning application
   */
  public FileCommander(AbstractApplicationFrame owner) {
    super(owner);
  }

  /**
   * Returns the file name of the icon.
   *
   * @return		the filename or null if no icon available
   */
  @Override
  public String getIconName() {
    return "filebrowser.png";
  }

  /**
   * Launches the functionality of the menu item.
   */
  @Override
  public void launch() {
    FileCommanderPanel panel = new FileCommanderPanel();
    createChildFrame(panel, GUIHelper.makeWider(GUIHelper.getDefaultDialogDimension()));
    if (m_Parameters.length > 0) {
      panel.setDirectory(m_Parameters[0], true);
      if (m_Parameters.length > 1)
        panel.setDirectory(m_Parameters[1], false);
      else
        panel.setDirectory(m_Parameters[0], false);
    }
  }

  /**
   * Returns the title of the window (and text of menuitem).
   *
   * @return 		the title
   */
  @Override
  public String getTitle() {
    return "File commander";
  }

  /**
   * Whether the panel can only be displayed once.
   *
   * @return		true if the panel can only be displayed once
   */
  @Override
  public boolean isSingleton() {
    return false;
  }

  /**
   * Returns the user mode, which determines visibility as well.
   *
   * @return		the user mode
   */
  @Override
  public UserMode getUserMode() {
    return UserMode.BASIC;
  }

  /**
   * Returns the category of the menu item in which it should appear, i.e.,
   * the name of the menu.
   *
   * @return		the category/menu name
   */
  @Override
  public String getCategory() {
    return CATEGORY_TOOLS;
  }
}